<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Photo;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use Image;

class PhotoController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.photo', [
            'photos' => Photo::get(),
        ]);
    }

    public function photo_add()
    {
        return view('admin.photo_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'photo' => 'required|file|image',
            'caption' => 'required',
            'status' => 'required',
        ]);

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $filename1 = 'photo_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
        }

        Photo::create([
            'photo' => $filename1,
            'caption' => $request->caption,
            'status' => $request->status
        ]);

        return Redirect()->route('admin.photo')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.photo_edit', [
            'photo' => Photo::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'caption' => 'required',
            'status' => 'required',
        ]);

        $photo = Photo::findOrFail($id);

        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$photo->photo));
            $filename1 = 'photo_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $photo->photo = $filename1;
        }
        $photo->caption = $request->caption;
        $photo->status  = $request->status;
        $photo->update();

        return Redirect()->route('admin.photo')->with('success', A_SUCCESS_DATA_UPDATE);
    }


    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $photo = Photo::find($id)->photo;
        unlink(public_path('uploads/'.$photo));
        Photo::find($id)->forceDelete();
        return Redirect()->route('admin.photo')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
