<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Slider;
use Illuminate\Http\Request;

use Carbon\Carbon;
use Image;

class SliderController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.slider', [
            'sliders' => Slider::get(),
        ]);
    }

    public function slider_add()
    {
        return view('admin.slider_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'photo' => 'required|file|image'
        ]);

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $filename = 'slider_'.md5(mt_rand(11111111,99999999)).'.'.$file->getClientOriginalExtension();
            $file->move(public_path('uploads'),$filename);
        }

        Slider::create([
            'heading'      => $request->heading,
            'full_content' => $request->full_content,
            'button1_text' => $request->button1_text,
            'button1_url'  => $request->button1_url,
            'button2_text' => $request->button2_text,
            'button2_url'  => $request->button2_url,
            'photo'        => $filename
        ]);

        return Redirect()->route('admin.slider')->with('success', A_SUCCESS_DATA_ADD);
    }


    public function edit_page($id)
    {
        $slider = Slider::find($id);
        return view('admin.slider_edit', compact('slider'));
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $slider = Slider::findOrFail($id);

        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            @unlink(public_path('uploads/'.$slider->photo));
            $filename = 'slider_'.md5(mt_rand(11111111,99999999)).'.'.$file->getClientOriginalExtension();
            $file->move(public_path('uploads'),$filename);
            $slider->photo = $filename;
        }

        $slider->heading      = $request->heading;
        $slider->full_content = $request->full_content;
        $slider->button1_text = $request->button1_text;
        $slider->button1_url  = $request->button1_url;
        $slider->button2_text = $request->button2_text;
        $slider->button2_url  = $request->button2_url;
        $slider->update();

        return Redirect()->route('admin.slider')->with('success', A_SUCCESS_DATA_UPDATE);
    }


    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $photo = Slider::find($id)->photo;
        unlink(public_path('uploads/' . $photo));
        Slider::find($id)->forceDelete();
        return Redirect()->route('admin.slider')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
