<?php

namespace App\Http\Controllers;

use App\Mail\ContactMail;
use App\Models\DynamicPage;
use App\Models\Faq;
use App\Models\News;
use App\Models\NewsCategory;
use App\Models\Page;
use App\Models\Partner;
use App\Models\Photo;
use App\Models\Portfolio;
use App\Models\PortfolioCategory;
use App\Models\PortfolioPhoto;
use App\Models\Service;
use App\Models\Setting;
use App\Models\Slider;
use App\Models\Team;
use App\Models\Testimonial;
use App\Models\WhyChoose;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use App\Models\User;
use Illuminate\Validation\Rule;

class FrontController extends Controller
{
    // Home Page
    public function index()
    {
        return view('front.home', [
            'sliders' => Slider::get(),
            'setting' => Setting::find(1),
            'faqs' => Faq::where('show_on_home', 'Yes')->get(),
            'news' => News::take(Setting::find(1)->total_recent_post_home)->get(),
            'partners' => Partner::get(),
            'photos' => Photo::where('status', 'Show')->get(),
            'protfolio_categories' => PortfolioCategory::get(),
            'portfolios' => Portfolio::where('show_on_home','Yes')->get(),
            'services' => Service::get(),
            'teams' => Team::get(),
            'testimonials' => Testimonial::get(),
            'why_chooses' => WhyChoose::get(),
            'page' => Page::find(1)
        ]);
    }

    // About Page
    public function about()
    {
        return view('front.about',[
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),
        ]);
    }

    // FAQ Page
    public function faq()
    {
        return view('front.faq',[
            'faqs' => Faq::get(),
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),
        ]);
    }

    // Gallery Page
    public function gallery()
    {
        return view('front.gallery',[
            'photos' => Photo::where('status', 'Show')->paginate(20),
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),
        ]);
    }

    // News Page
    public function news()
    {
        return view('front.news',[
            'news' => News::paginate(15),
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),
        ]);
    }

    // Portfolio
    public function portfolio()
    {
        return view('front.portfolio',[
            'portfolio_categorys' => PortfolioCategory::get(),
            'portfolios' => Portfolio::get(),
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),

        ]);
    }

    // Portfolio Single
    public function portfolio_view ($slug)
    {
        $portfolio = Portfolio::where('slug',$slug)->first();
        return view('front.portfolio_view',[
            'portfolios' => Portfolio::get(),
            'portfolio' => $portfolio,
            'portfolio_photos' => PortfolioPhoto::where('portfolio_id', $portfolio->id)->get(),
            'portfolio_photo_total' => PortfolioPhoto::where('portfolio_id', $portfolio->id)->count(),
            'sliders' => Slider::get(),
        ]);
    }

    // News Single Page
    public function news_view ($slug)
    {
        $news_single = News::where('slug',$slug)->first();

        $old_total_view = News::find($news_single->id)->total_view;
        $current_total_view = $old_total_view + 1;

        News::find($news_single->id)->update([
            "total_view" => $current_total_view,
        ]);

        return view('front.news_view',[
            'newss' => News::get(),
            'news' => News::find($news_single->id),
            'news_categorys' => NewsCategory::all(),
            'news_latest' => News::orderBy('id', 'desc')->get(),
            'news_popular' => News::orderBy('total_view', 'desc')->get(),
            'page' => Page::find(1),
            'setting' => Setting::find(1)
        ]);
    }

    // News Category Page
    public function news_category_view ($slug)
    {
        $category_single = NewsCategory::where('slug',$slug)->first();
        return view('front.news_category',[
            'news_all' => News::where('category_id', $category_single->id)->get(),
            'news' => News::find($category_single->id),
            'news_category_single' => NewsCategory::find($category_single->id),
        ]);
    }

    // Service Page
    public function service()
    {
        return view('front.service', [
            'services' => Service::paginate(9),
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),
        ]);
    }

    // Service Detail
    public function service_view($slug)
    {
        return view('front.service_view', [
            'service' => Service::where('slug',$slug)->first(),
            'services' => Service::get(),
        ]);
    }

    // search
    public function search(Request $req)
    {
        return view('front.search', [
            'items' => News::where('title','like','%'. $req->search_string.'%')->orWhere('full_content','like','%'. $req->search_string.'%')->get(),
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),
            'search_string' => $req->search_string
        ]);
    }

    // Testimonial
    public function testimonial()
    {
        return view('front.testimonial', [
            'testimonials' => Testimonial::get(),
            'page_data' => Page::find(1),
            'setting_data' => Setting::find(1),
        ]);
    }

    // Term
    public function term()
    {
        return view('front.term', [
            'term' => Page::find(1),
            'page' => Page::find(1),
            'setting' => Setting::find(1),
        ]);
    }

    // Privacy
    public function privacy()
    {
        return view('front.privacy', [
            'privacy' => Page::find(1),
            'page' => Page::find(1),
            'setting' => Setting::find(1),
        ]);
    }

    // Contact Page
    public function contact()
    {
        return view('front.contact',[
            'page' => Page::find(1),
            'setting' => Setting::find(1),
        ]);
    }

   // Contact Page Send Email
    public function contact_send_email(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return response()->json(['code'=>2,'success_message'=>env('PROJECT_NOTIFICATION')]);
        }

        $validator = \Validator::make($request->all(),[
            'name'=>'required',
            'email' => 'required|email',
            'message' => 'required',
            'g-recaptcha-response' => 'required'
        ], [
            'name.required' => ERROR_EMPTY_NAME,
            'email.required' => ERROR_EMPTY_EMAIL,
            'email.email' => ERROR_INVALID_EMAIL,
            'message.required' => ERROR_EMPTY_MESSAGE,
            'g-recaptcha-response.required' => ERROR_RECAPTCHA
        ]);

        if(!$validator->passes())
        {
            return response()->json(['code'=>0,'error_message'=>$validator->errors()->toArray()]);
        }
        else
        {
            $subject = SUBJECT_CONTACT_EMAIL_SEND;
            $admin_data = User::where('id',1)->first();

            $message = 'Name: '.$request->name.'<br>';
            $message .= 'Phone: '.$request->phone.'<br>';
            $message .= 'Email: '.$request->email.'<br>';
            $message .= 'Message: '.$request->message;

            Mail::to($admin_data->email)->send(new ContactMail($subject,$message));

            return response()->json(['code'=>1,'success_message'=>SUCCESS_CONTACT_EMAIL_SEND]);
        }
    }

    // Dynamic Page
    public function dynamic_page($slug)
    {
        return view('front.dynamic_page', [
            'dynamic_page_single' => DynamicPage::where('slug',$slug)->first(),
            'setting' => Setting::find(1),
        ]);
    }

}
